# Terminal Image Viewer
A python python package to display images in your terminal, with colored characters.
## Installation
```bash
pip install terminalImgViewer
```
## Usage
```python
from terminalImgViewer import getTerminalImage

terminalImage = getTerminalImage("IMAGE_PATH", RESULT_WIDTH)
print(terminalImage)
```
## Result
![image](https://github.com/judemont/terminalImgViewer/assets/96385330/194e6693-fa22-46b0-bc36-4f69e24510ef)
